<?php

/**
 * Robin Google Maps Shortcode
 *
 * @version 1.0
 * @package Robin
 */
class WPBakeryShortCode_Robin_Gmaps extends WPBakeryShortCode {

	public function convertAttributesToNewMarker( $atts ) {
		if ( isset( $atts['markers'] ) && strlen( $atts['markers'] ) > 0 ) {
			$markers = vc_param_group_parse_atts( $atts['markers'] );

			if ( ! is_array( $markers ) ) {
				$temp         = explode( ',', $atts['markers'] );
				$paramMarkers = array();

				foreach ( $temp as $marker ) {
					$data = explode( '|', $marker );

					$newMarker            = array();
					$newMarker['address'] = isset( $data[0] ) ? $data[0] : '';
					$newMarker['icon']    = isset( $data[1] ) ? $data[1] : '';
					$newMarker['info']    = isset( $data[2] ) ? $data[2] : '';

					$paramMarkers[] = $newMarker;
				}

				$atts['markers'] = urlencode( json_encode( $paramMarkers ) );

			}

			return $atts;
		}
	}
}

// Mapping shortcode.
vc_map( array(
			'name'        => esc_html__( 'Google Maps', 'tm-robin' ),
			'base'        => 'robin_gmaps',
			'icon'        => 'robin-icon-gmaps',
			'category'    => sprintf( esc_html__( 'by %s', 'tm-robin' ), TM_ROBIN_THEME_NAME ),
			'description' => esc_html__( 'Map block', 'tm-robin' ),
			'params'      => array(
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__( 'Height', 'tm-robin' ),
					'param_name'  => 'map_height',
					'value'       => '500',
					'description' => esc_html__( 'Enter map height (in pixels or %)', 'tm-robin' ),
				),
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__( 'Width', 'tm-robin' ),
					'param_name'  => 'map_width',
					'value'       => '100%',
					'description' => esc_html__( 'Enter map width (in pixels or %)', 'tm-robin' ),
				),
				array(
					'type'        => 'number',
					'heading'     => esc_html__( 'Zoom level', 'tm-robin' ),
					'param_name'  => 'zoom_lvl',
					'value'       => 16,
					'max'         => 17,
					'min'         => 0,
					'description' => esc_html__( 'Map zoom level', 'tm-robin' ),
				),
				array(
					'type'       => 'checkbox',
					'param_name' => 'scroll_whell',
					'value'      => array(
						esc_html__( 'Enable mouse scroll wheel zoom', 'tm-robin' ) => 'yes',
					),
				),
				array(
					'type'        => 'dropdown',
					'heading'     => esc_html__( 'Map type', 'tm-robin' ),
					'admin_label' => true,
					'param_name'  => 'map_type',
					'description' => esc_html__( 'Choose a map type', 'tm-robin' ),
					'value'       => array(
						'Roadmap'   => 'ROADMAP',
						'Satellite' => 'SATELLITE',
						'Hybrid'    => 'HYBRID',
						'Terrain'   => 'TERRAIN',
					),
				),
				array(
					'type'        => 'dropdown',
					'heading'     => esc_html__( 'Map style', 'tm-robin' ),
					'admin_label' => true,
					'param_name'  => 'map_style',
					'description' => esc_html__( 'Choose a map style. This approach changes the style of the Roadmap types (base imagery in terrain and satellite views is not affected, but roads, labels, etc. respect styling rules)', 'tm-robin' ),
					'value'       => array(
						'Default'          => 'default',
						'Grayscale'        => 'style1',
						'Subtle Grayscale' => 'style2',
						'Apple Maps-esque' => 'style3',
						'Pale Dawn'        => 'style4',
						'Muted Blue'       => 'style5',
						'Paper'            => 'style6',
						'Light Dream'      => 'style7',
						'Retro'            => 'style8',
						'Avocado World'    => 'style9',
						'Facebook'         => 'style10',
						'Custom'           => 'custom',
					),
				),
				array(
					'type'        => 'textarea_raw_html',
					'heading'     => esc_html__( 'Map style snippet', 'tm-robin' ),
					'param_name'  => 'map_style_snippet',
					'description' => sprintf( wp_kses( __( 'To get the style snippet, visit <a href="%s" target="_blank">Sanzzymaps</a> or <a href="%s" target="_blank">Mapstylr</a>.', 'tm-robin' ),
													   array(
														   'a' => array(
															   'href'   => array(),
															   'target' => array(),
														   )
													   ) ), esc_url( 'https://sanzzymaps.com/' ), esc_url( 'http://www.mapstylr.com/' )
					),
					'dependency'  => array(
						'element' => 'map_style',
						'value'   => 'custom',
					),
				),
				array(
					'group'       => esc_html__( 'Markers', 'tm-robin' ),
					'type'        => 'param_group',
					'heading'     => esc_html__( 'Markers', 'tm-robin' ),
					'param_name'  => 'markers',
					'description' => esc_html__( 'You can add multiple markers to the map', 'tm-robin' ),
					'value'       => urlencode( json_encode( array(
																 array(
																	 'address' => '40.7590615,-73.969231',
																 ),
															 ) ) ),
					'params'      => array(
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Address or Coordinate', 'tm-robin' ),
							'param_name'  => 'address',
							'admin_label' => true,
							'description' => sprintf( wp_kses( __( 'Enter address or coordinate. Find coordinates using the name and/or address of the place using <a href="%s" target="_blank">this simple tool here.</a>', 'tm-robin' ),
															   array(
																   'a' => array(
																	   'href'   => array(),
																	   'target' => array(),
																   )
															   ) ), esc_url( 'http://universimmedia.pagesperso-orange.fr/geo/loc.htm' )
							),
						),
						array(
							'type'        => 'attach_image',
							'heading'     => esc_html__( 'Marker icon', 'tm-robin' ),
							'param_name'  => 'icon',
							'description' => esc_html__( 'Choose a image for marker address', 'tm-robin' ),
						),
						array(
							'type'        => 'textarea',
							'heading'     => esc_html__( 'Marker Information', 'tm-robin' ),
							'param_name'  => 'info',
							'description' => esc_html__( 'Content for info window', 'tm-robin' ),
						),
					),
				),
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__( 'Google Maps API Key (optional)', 'tm-robin' ),
					'param_name'  => 'api_key',
					'description' => sprintf( wp_kses( __( 'Follow <a href="%s" target="_blank">this link</a> and click <strong>GET A KEY</strong> button. If you leave it empty, the API Key will be put in by default from our key.', 'tm-robin' ),
													   array(
														   'a'      => array(
															   'href'   => array(),
															   'target' => array(),
														   ),
														   'strong' => array()
													   ) ), esc_url( 'https://developers.google.com/maps/documentation/javascript/get-api-key#get-an-api-key' )
					)
				),
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__( 'Extra class name', 'tm-robin' ),
					'param_name'  => 'el_class',
					'description' => esc_html__( 'If you want to use multiple Google Maps in one page, please add a class name for them.', 'tm-robin' ),
				),
				TM_Robin_VC::get_param( 'css' ),
			),
		) );
